@@ -4,7 +4,7 @@ from importlib import import_module
 import warnings
 warnings.simplefilter("ignore")
 
-from akerbp.mlops.cdf.helpers import get_function_metadata
+import akerbp.mlops.cdf.helpers as cdf
 from akerbp.mlops.core import logger, config
 service_name = config.envs.service_name
 logging=logger.get_logger("mlops_cdf")
@@ -12,11 +12,12 @@ logging=logger.get_logger("mlops_cdf")
 service = import_module(f"akerbp.mlops.services.{service_name}").service
 
 
-def handle(data, client, secrets, function_call_info):
+def handle(data, secrets, function_call_info):
    try:
-      config.update_cdf_keys(secrets)
       output = service(data, secrets)
-      metadata = get_function_metadata(client, function_call_info)
+      cdf.api_keys = secrets
+      cdf.set_up_cdf_client(context='deploy')
+      metadata = cdf.get_function_metadata(function_call_info)
       output.update(metadata)
       return output
    except Exception:
