@@ -55,6 +55,9 @@ def get_client(api_key, api_key_label=None):
     """
     Create a CDF client with a given api key
     """
+    if not api_key:
+        raise ValueError("CDF api key is missing")
+    
     if api_key_label == 'functions':
         from cognite.experimental import CogniteClient
         logging.warning("Imported CogniteClient from cognite.experimental")
@@ -155,7 +158,8 @@ def deploy_function(
             raise Exception(f"Function deployment error: {function.error=}")
 
 
-def get_function_metadata(client, function_call_info):
+def get_function_metadata(function_call_info):
+   client = global_client["functions"]
    function_id=function_call_info["function_id"]
    function = client.functions.retrieve(id=function_id)
    metadata = dict(
